#!/bin/zsh

### parameter setting
# grid region east/west/south/north
#
region=141:53/142:02/39:18/39:23
#region=127:00/139:00/28:00/34:30
#region=127:00/149:00/28:00/44:30

# map projection and scale
proj=M20		
# boundary tick info
ticks=a1mf1mg1m
#ticks=a1f1g1

# boundary frame info
frame=WSne+tOtsuchi_ETOPO  

# color table min/maz/interval
climit=-150/0/10	
# contour interval
cint=10
# contour digit
cdigit=10
# contour min/max
limit=-150/-0       
# conlor table
cptfile=haxby_area.cpt	
# shade direction
light=0/90      

# output postscript file name
#psfile=KT-22-5_ETOPO_test.ps	
psfile=Otsuchi_ETOPO_test.ps	
backgrdsamp=ETOPO1_Ice_g_gmt4.grd
station=Otsuchi_sta.txt

# textsize, font, color, justification
textfont="+f12p,Helvetica,-=0.5p,blue+jBL" 


### Main commands
if [ ! -e $backgrdsamp ];then
  echo "Gridfile", $backgrdsamp, " not exists."
  echo "Dowload this file from https://www.ngdc.noaa.gov/mgg/global/relief/ETOPO1/data/ice_surface/grid_registered/netcdf/"
  exit
fi

# making color table
gmt makecpt -Chaxby -T$climit -Z > $cptfile

gmt grdimage $backgrdsamp -R$region -J$proj -C$cptfile  -K -V > $psfile
gmt grdcontour $backgrdsamp -R$region -J$proj -C$cint -A$cdigit -L$limit -W0.1 -K -O -V  >> $psfile

gmt pscoast -R$region -J$proj -Df -Ggray -W0.1,black -K -V -O >> $psfile

#gmt psscale -D5/-1/10/0.5h -C$cptfile -Bf50a150 -K -O >> $psfile
gmt psscale -D21/5/10/0.5 -C$cptfile -Bf10a50g50 -K -O >> $psfile

# psxy collects lat lon values in 1st and 2nd columns 
gmt psxy $station -R$region -J$proj -Sc0.1 -Gblue -K -O -V >> $psfile

# pstext collects statkion names in 3rd column
gmt pstext $station -R$region -J$proj -F$textfont -K -O -V >> $psfile
gmt psbasemap -R$region -J$proj -B$ticks -B$frame  -O -V >> $psfile

